from distutils.core import setup
setup(
  name = 'python-tee',
  packages = ['tee'],
  version = '0.0.5',
  license='MIT',
  description = '',
  author = 'Dante Biase',
  url = 'https://github.com/dante-biase/python-tee',
  download_url = 'https://github.com/dante-biase/python-tee/archive/v0.0.5.tar.gz',
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
  ],
)